@@ -63,6 +63,8 @@ class Protocol(asyncio.Protocol):
         buffers for each request since parts of the requests may be received
         within diffrent package fragments.
         """
+        # print('RECV!!')
+        # print(data)
         if self._buf is None:
             data = self._tmp + data
 
@@ -109,7 +111,7 @@ class Protocol(asyncio.Protocol):
             self.data_received(more)
 
     def write(self, data: bytes):
-        # call_id, = struct.unpack_from('<L', data, offset=12)
+        call_id, = struct.unpack_from('<L', data, offset=12)
         # print('SEND!! Call Id:', call_id)
         # print(data)
         self._transport.write(data)
